@@ -174,6 +174,19 @@ sub to_legacy {
     return $result;
 }
 
+sub extra_details {
+    my $self = shift;
+
+    require Test::Stream::Tester::Events;
+
+    return (
+        diag => Test::Stream::Tester::Events->new(@{$self->diag || []}) || undef,
+        bool      => $self->bool      || 0,
+        name      => $self->name      || undef,
+        real_bool => $self->real_bool || 0
+    );
+}
+
 1;
 
 __END__
@@ -218,11 +231,14 @@ VIM's sort function).
 
 =head1 COPYRIGHT
 
+There has been a lot of code migration between modules,
+here are all the original copyrights together:
+
 =over 4
 
 =item Test::Stream
 
-=item Test::Tester2
+=item Test::Stream::Tester
 
 Copyright 2014 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 
