@@ -53,6 +53,15 @@ sub to_tap {
     return [OUT_STD, "$plan\n"];
 }
 
+sub extra_details {
+    my $self = shift;
+    return (
+        max       => $self->max       || 0,
+        directive => $self->directive || undef,
+        reason    => $self->reason    || undef
+    );
+}
+
 1;
 
 __END__
@@ -97,11 +106,14 @@ VIM's sort function).
 
 =head1 COPYRIGHT
 
+There has been a lot of code migration between modules,
+here are all the original copyrights together:
+
 =over 4
 
 =item Test::Stream
 
-=item Test::Tester2
+=item Test::Stream::Tester
 
 Copyright 2014 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 
